"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const Block = __importStar(require("multiformats/block"));
const cid_1 = require("multiformats/cid");
const dagPb = __importStar(require("@ipld/dag-pb"));
const dagCbor = __importStar(require("@ipld/dag-cbor"));
const sha2_1 = require("multiformats/hashes/sha2");
const base58_1 = require("multiformats/bases/base58");
const mhtype = 'sha2-256';
const defaultBase = base58_1.base58btc;
const unsupportedCodecError = () => new Error('unsupported codec');
const cidifyString = (str) => {
    if (!str) {
        return str;
    }
    if (Array.isArray(str)) {
        return str.map(cidifyString);
    }
    return cid_1.CID.parse(str);
};
const stringifyCid = (cid, options = {}) => {
    if (!cid || typeof cid === 'string') {
        return cid;
    }
    if (Array.isArray(cid)) {
        return cid.map(stringifyCid);
    }
    const base = options.base || defaultBase;
    if (cid['/']) {
        return cid.toString(defaultBase);
    }
    return cid.toString(base);
};
const codecCodes = {
    [dagPb.code]: dagPb,
    [dagCbor.code]: dagCbor
};
const codecMap = {
    // staying backward compatible
    // old writeObj function was never raw codec; defaulted to cbor via ipfs.dag
    raw: dagCbor,
    'dag-pb': dagPb,
    'dag-cbor': dagCbor
};
async function read(ipfs, cid, options = {}) {
    cid = cidifyString(stringifyCid(cid));
    const codec = codecCodes[cid.code];
    if (!codec)
        throw unsupportedCodecError();
    const bytes = await ipfs.block.get(cid, { timeout: options.timeout });
    const block = await Block.decode({ bytes, codec, hasher: sha2_1.sha256 });
    if (block.cid.code === dagPb.code) {
        return JSON.parse(new TextDecoder().decode(block.value.Data));
    }
    if (block.cid.code === dagCbor.code) {
        const value = block.value;
        const links = options.links || [];
        links.forEach((prop) => {
            if (value[prop]) {
                value[prop] = stringifyCid(value[prop], options);
            }
        });
        return value;
    }
}
async function write(ipfs, format, value, options = {}) {
    if (options.format === 'dag-pb')
        format = options.format;
    const codec = codecMap[format];
    if (!codec)
        throw unsupportedCodecError();
    if (codec.code === dagPb.code) {
        value = typeof value === 'string' ? value : JSON.stringify(value);
        value = { Data: new TextEncoder().encode(value), Links: [] };
    }
    if (codec.code === dagCbor.code) {
        const links = options.links || [];
        links.forEach((prop) => {
            if (value[prop]) {
                value[prop] = cidifyString(value[prop]);
            }
        });
    }
    const block = await Block.encode({ value, codec, hasher: sha2_1.sha256 });
    await ipfs.block.put(block.bytes, {
        /* cid: block.cid.bytes, */
        version: block.cid.version,
        format,
        mhtype,
        pin: options.pin,
        timeout: options.timeout
    });
    const cid = codec.code === dagPb.code
        ? block.cid.toV0()
        : block.cid;
    const cidString = cid.toString(options.base || defaultBase);
    return cidString;
}
exports.default = {
    read,
    write
};
//# sourceMappingURL=index.js.map